==> 0.0.1.tar.gz: lib/polymer_http_behavior.dart <==
/**
 * Created by lejard_h on 11/10/15.
 */

library polymer_http_behavior;

import "package:polymer/polymer.dart";
import 'package:http/browser_client.dart';
import 'dart:async';
import 'package:http/http.dart' as http;
import 'dart:convert';

@behavior
abstract class PolymerHttpBehavior {
  BrowserClient _http = new BrowserClient();

  _computeUrlParams(String url, Map params) {
    if (params.length > 0) {
      url += "?";
      params.forEach((key, value) {
        url += "$key=$value&";
      });
    }
    return url;
  }

  Future<http.Response> httpGet(String url,
          {Map params, Map<String, String> headers}) =>
      _http.get(_computeUrlParams(url, params), headers: headers);

  Future<http.Response> httpPost(String url,
          {body, Map params, Map<String, String> headers, Encoding encoding}) =>
      _http.post(_computeUrlParams(url, params), body: body, headers: headers, encoding: encoding);

  Future<http.Response> httpPut(String url,
      {body, Map params, Map<String, String> headers, Encoding encoding}) =>
      _http.put(_computeUrlParams(url, params), body: body, headers: headers, encoding: encoding);

  Future<http.Response> httpPatch(String url,
      {body, Map params, Map<String, String> headers, Encoding encoding}) =>
      _http.patch(_computeUrlParams(url, params), body: body, headers: headers, encoding: encoding);

  Future<http.Response> httpDelete(String url,
      {Map params, Map<String, String> headers}) =>
      _http.delete(_computeUrlParams(url, params), headers: headers);

  Future<http.Response> httpHead(String url,
      {Map params, Map<String, String> headers}) =>
      _http.head(_computeUrlParams(url, params), headers: headers);
}

==> 0.0.2.tar.gz: lib/polymer_http_behavior.dart <==
/**
 * Created by lejard_h on 11/10/15.
 */

library polymer_http_behavior;

import "package:polymer/polymer.dart";
import 'package:http/browser_client.dart';
import 'dart:async';
import 'package:http/http.dart' as http;
import 'dart:convert';

@behavior
abstract class PolymerHttpBehavior {
  BrowserClient _http = new BrowserClient();

  _computeUrlParams(String url, Map params) {
    if (params != null && params.length > 0) {
      url += "?";
      params.forEach((key, value) {
        url += "$key=$value&";
      });
    }
    return url;
  }

  Future<http.Response> httpGet(String url,
          {Map params, Map<String, String> headers}) =>
      _http.get(_computeUrlParams(url, params), headers: headers);

  Future<http.Response> httpPost(String url,
          {body, Map params, Map<String, String> headers, Encoding encoding}) =>
      _http.post(_computeUrlParams(url, params), body:body, headers: headers, encoding: encoding);

  Future<http.Response> httpPut(String url,
      {body, Map params, Map<String, String> headers, Encoding encoding}) =>
      _http.put(_computeUrlParams(url, params), body: body, headers: headers, encoding: encoding);

  Future<http.Response> httpPatch(String url,
      {body, Map params, Map<String, String> headers, Encoding encoding}) =>
      _http.patch(_computeUrlParams(url, params), body: body, headers: headers, encoding: encoding);

  Future<http.Response> httpDelete(String url,
      {Map params, Map<String, String> headers}) =>
      _http.delete(_computeUrlParams(url, params), headers: headers);

  Future<http.Response> httpHead(String url,
      {Map params, Map<String, String> headers}) =>
      _http.head(_computeUrlParams(url, params), headers: headers);
}
